django\_sorcery.management.commands.sorcery\_downgrade module
=============================================================

.. automodule:: django_sorcery.management.commands.sorcery_downgrade
   :members:
   :undoc-members:
   :show-inheritance:
